@@ -6,14 +6,19 @@ import pickle
 
 def populationComparaison(nameOfFile, resFolder, globParam, conditions, genotypes, outputFolder):
 
-  if os.path.exists(outputFolder+nameOfFile):
-    shutil.rmtree(outputFolder+nameOfFile)
-  os.mkdir(outputFolder+nameOfFile)
+  outputFolderResult = os.path.join(outputFolder, nameOfFile)
 
-  infile = open(resFolder + nameOfFile,'rb')
+  if os.path.exists(outputFolderResult):
+    shutil.rmtree(outputFolderResult)
+  os.mkdir(outputFolderResult)
+
+  infile = open(os.path.join(resFolder, nameOfFile),'rb')
   dfParam = pickle.load(infile)
   infile.close()
   
+  columnsForRawDataExport = ['index', 'Trial_ID', 'Well_ID', 'NumBout', 'BoutStart', 'BoutEnd', 'Condition', 'Genotype'] + globParam
+  dfParam[columnsForRawDataExport].to_excel(os.path.join(outputFolderResult, 'globalParametersInsideCategories.xlsx'))
+  
   nbLines   = int(math.sqrt(len(globParam)))
   nbColumns = math.ceil(len(globParam) / nbLines)
   fig, tabAx = plt.subplots(nbLines, nbColumns, figsize=(22.9, 8.8))
@@ -36,4 +41,4 @@ def populationComparaison(nameOfFile, resFolder, globParam, conditions, genotype
       tabAx[int(idx/nbColumns), idx%nbColumns].set_title(parameter)
       tabAx[int(idx/nbColumns), idx%nbColumns].boxplot(concatenatedValues)
       tabAx[int(idx/nbColumns), idx%nbColumns].set_xticklabels(labels)
-  plt.savefig(outputFolder+nameOfFile+'/globalParametersInsideCategories.png')
+  plt.savefig(os.path.join(outputFolderResult, 'globalParametersInsideCategories.png'))
